import setuptools

setuptools.setup(
    #name="haiji-filler'
    name="juyoshid1",
    version="0.0.1",
    author="Team haiji",
    author_email="haiji@student.42tokyo.jp",
    description="",
    package_dir={'src/': 'src'},
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
                 ],
                 )
